==> tmw-0.0.17.tar.gz: tmw-0.0.17/src/gui/buddywindow.cpp <==
/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: buddywindow.cpp,v 1.14 2005/08/28 20:31:56 der_doener Exp $
 */

#include "buddywindow.h"

#include <guichan/widgets/listbox.hpp>

#include "button.h"
#include "chat.h"
#include "scrollarea.h"

extern ChatWindow *chatWindow;

BuddyWindow::BuddyWindow():
    Window("Buddy")
{
    setContentSize(124, 202);

    listbox = new gcn::ListBox();
    listbox->setListModel(this);

    scrollArea = new ScrollArea(listbox);
    scrollArea->setDimension(gcn::Rectangle(
                7, 5, 110, 170));
    add(scrollArea);

    talk = new Button("Talk");
    talk->setPosition(2,180);
    talk->addActionListener(this);
    talk->setEventId("Talk");
    remove = new Button("Remove");
    remove->addActionListener(this);
    remove->setEventId("Remove");
    remove->setPosition(talk->getWidth()+2,180);
    cancel = new Button("Cancel");
    cancel->addActionListener(this);
    cancel->setEventId("Cancel");
    cancel->setPosition(talk->getWidth()+remove->getWidth()+2,180);

    add(talk);
    add(remove);
    add(cancel);
}

BuddyWindow::~BuddyWindow()
{
    delete listbox;
    delete scrollArea;
    delete talk;
    delete remove;
    delete cancel;
}

void BuddyWindow::action(const std::string& eventId)
{
    if (eventId == "Talk") {
        int selected = listbox->getSelected();
        if ( selected > -1 )
        {
            std::string who = getElementAt(selected);
            chatWindow->setInputText(who +": ");
        }
    }
    else if (eventId == "Remove") {
        int selected = listbox->getSelected();
        if ( selected > -1 )
        {
            std::string who = getElementAt(selected);
            removeBuddy(who);
        }
    }
    else if (eventId == "Cancel") {
        setVisible(false);
    }
}

==> tmw-0.0.19.tar.gz: tmw-0.0.19/src/gui/buddywindow.cpp <==
/*
 *  The Mana World
 *  Copyright 2004 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: buddywindow.cpp 2112 2006-01-22 13:31:13Z der_doener $
 */

#include "buddywindow.h"

#include <guichan/widgets/listbox.hpp>

#include "button.h"
#include "chat.h"
#include "scrollarea.h"

#include "../resources/buddylist.h"

extern ChatWindow *chatWindow;

BuddyWindow::BuddyWindow():
    Window("Buddy")
{
    setContentSize(124, 202);

    mBuddyList = new BuddyList();

    mListbox = new gcn::ListBox();
    mListbox->setListModel(mBuddyList);

    ScrollArea *scrollArea = new ScrollArea(mListbox);
    scrollArea->setDimension(gcn::Rectangle(
                7, 5, 110, 170));
    add(scrollArea);

    Button *talk = new Button("Talk");
    talk->setPosition(2,180);
    talk->addActionListener(this);
    talk->setEventId("Talk");
    Button *remove = new Button("Remove");
    remove->addActionListener(this);
    remove->setEventId("Remove");
    remove->setPosition(talk->getWidth()+2,180);
    Button *cancel = new Button("Cancel");
    cancel->addActionListener(this);
    cancel->setEventId("Cancel");
    cancel->setPosition(talk->getWidth()+remove->getWidth()+2,180);

    add(talk);
    add(remove);
    add(cancel);
}

void BuddyWindow::action(const std::string& eventId)
{
    if (eventId == "Talk") {
        int selected = mListbox->getSelected();
        if ( selected > -1 )
        {
            std::string who = mBuddyList->getElementAt(selected);
            chatWindow->setInputText(who +": ");
        }
    }
    else if (eventId == "Remove") {
        int selected = mListbox->getSelected();
        if ( selected > -1 )
        {
            std::string who = mBuddyList->getElementAt(selected);
            mBuddyList->removeBuddy(who);
        }
    }
    else if (eventId == "Cancel") {
        setVisible(false);
    }
}
